@@ -1,9 +1,9 @@
 package Sah::Schema::date::dow_name::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Day-of-week name (abbreviated or full, in English)',
@@ -37,7 +37,7 @@ Sah::Schema::date::dow_name::en - Day-of-week name (abbreviated or full, in Engl
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::date::dow_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.013 of Sah::Schema::date::dow_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -73,15 +73,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "su"  # valid
 
- undef  # valid
+ "mOn"  # valid
 
- undef  # valid
+ "TUESDAY"  # valid
 
- undef  # INVALID
+ "foo"  # INVALID
 
 =head1 HOMEPAGE
 
