@@ -1,9 +1,9 @@
 package Sah::Schema::date::dow_num;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [int => {
     summary => 'Day-of-week number (1-7, 1=Monday)',
@@ -36,7 +36,7 @@ Sah::Schema::date::dow_num - Day-of-week number (1-7, 1=Monday)
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.013 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -50,7 +50,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -72,15 +72,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # INVALID
+ 0  # INVALID
 
- undef  # valid
+ 1  # valid
 
- undef  # valid
+ 7  # valid
 
- undef  # INVALID
+ 8  # INVALID
 
 =head1 HOMEPAGE
 
