@@ -1,9 +1,9 @@
 package Sah::Schema::date::month::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Month number/name (abbreviated or full, in English)',
@@ -39,7 +39,7 @@ Sah::Schema::date::month::en - Month number/name (abbreviated or full, in Englis
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.013 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -75,19 +75,19 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ 1  # valid
 
- undef  # valid
+ "jan"  # valid
 
- undef  # valid
+ "FeB"  # valid
 
- undef  # valid
+ "March"  # valid
 
- undef  # INVALID
+ "foo"  # INVALID
 
- undef  # INVALID
+ 13  # INVALID
 
 =head1 HOMEPAGE
 
