@@ -1,9 +1,9 @@
 package Sah::Schema::date::month_nums;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of month numbers',
@@ -38,7 +38,7 @@ Sah::Schema::date::month_nums - Array of month numbers
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.013 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -74,21 +74,21 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ ""  # valid, becomes []
 
- undef  # INVALID
+ 0  # INVALID
 
- undef  # valid
+ 1  # valid, becomes [1]
 
- undef  # valid
+ [1]  # valid
 
- undef  # valid
+ [1,12]  # valid
 
- undef  # valid
+ "1,12"  # valid, becomes [1,12]
 
- undef  # INVALID
+ [1,12,13]  # INVALID
 
- undef  # INVALID
+ "1,12,13"  # INVALID
 
 =head1 HOMEPAGE
 
