@@ -1,9 +1,9 @@
 package Sah::Schema::date::tz_offset;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 BEGIN {
 
@@ -90,7 +90,7 @@ Sah::Schema::date::tz_offset - Timezone offset in seconds from UTC
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.013 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -126,29 +126,29 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "UTC"  # valid, becomes 0
 
- undef  # valid
+ 3600  # valid, becomes 3600
 
- undef  # valid
+ -43200  # valid, becomes -43200
 
- undef  # valid
+ -12  # valid, becomes -43200
 
- undef  # valid
+ -1200  # valid, becomes -43200
 
- undef  # valid
+ "-12:00"  # valid, becomes -43200
 
- undef  # valid
+ "UTC-12"  # valid, becomes -43200
 
- undef  # valid
+ "UTC-1200"  # valid, becomes -43200
 
- undef  # valid
+ "UTC+12:45"  # valid, becomes 45900
 
- undef  # INVALID
+ "UTC-13"  # INVALID
 
- undef  # INVALID (Unknown offset)
+ "UTC+12:01"  # INVALID (Unknown offset)
 
 =head1 DESCRIPTION
 
